# FAQ

Setup & installation guide:

- {doc}`setup`

Edges cases, warnings, and errors:

- {doc}`initialize`
- {doc}`initialize-set-env`
- {doc}`inconsistent-packages-parents-store`
- {doc}`inconsistent-packages-parents-no-store`
- {doc}`example-project/index`
- {doc}`example-project-uninitialized/index`
- {doc}`example-after-init-set-filename`
- {doc}`publish-set-version`
- {doc}`publish-without-title`
- {doc}`publish-without-saving`
- {doc}`publish-not-last-cell`
- {doc}`publish-wrapper`
- {doc}`trigger-exit-upon-init`
- {doc}`not-initialized`
- {doc}`internal-functions`

```{toctree}
:maxdepth: 1
:hidden:

setup
initialize
initialize-set-env
inconsistent-packages-parents-store
inconsistent-packages-parents-no-store
example-project/index
example-project-uninitialized/index
example-after-init-set-filename
publish-set-version
publish-without-title
publish-without-saving
publish-not-last-cell
publish-wrapper
trigger-exit-upon-init
not-initialized
internal-functions
```
